@@ -16,6 +16,8 @@
 #include "vrslstfrm.h"
 #include <utilstr.h>
 #include <filemgr.h>
+#include "editentryfrm.h"
+#include "versesel.h"
 
 //---------------------------------------------------------------------------
 #pragma resource "*.dfm"
@@ -67,8 +69,8 @@ void TForm1::BuildRTFHeader(char *buf, char *font, int max)
 	
 	sprintf(buf1, "{\\rtf1\\ansi");
 	if (font)
-		sprintf(buf2, "{\\fonttbl{\\f0\\fdecor\\fprq2 %s;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f2\\froman\\fcharset2\\fprq2 Symbol;}{\\f3\\froman\\fcharset2\\fprq2 Symbol;}}", font);
-	else sprintf(buf2, "{\\fonttbl{\\f0\\fdecor\\fprq2 Times New Roman;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f2\\froman\\fcharset2\\fprq2 Symbol;}{\\f3\\froman\\fcharset2\\fprq2 Symbol;}}");
+		sprintf(buf2, "{\\fonttbl{\\f0\\fdecor\\fprq2 %s;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f2\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f3\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f4\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f7\\froman\\fcharset2\\fprq2 Symbol;}{\\f8\\froman\\fcharset2\\fprq2 Symbol;}}", font);
+	else sprintf(buf2, "{\\fonttbl{\\f0\\fdecor\\fprq2 Times New Roman;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f7\\froman\\fcharset2\\fprq2 Symbol;}{\\f8\\froman\\fcharset2\\fprq2 Symbol;}}");
 	strcat(buf1, buf2);
 
 	if ((sit = optionsconf->Sections.find("Appearance")) != optionsconf->Sections.end()) {
@@ -138,7 +140,11 @@ char TForm1::CreateCommentPane(SWModule *mod) {
 		mod->Disp(*displays.insert(displays.begin(), new RTFDisp((SWDispRTF *)newrtf)));
 		((SWDispRTF *)newrtf)->ScrollBars = ssVertical;
 		((SWDispRTF *)newrtf)->ReadOnly = true;
-		((SWDispRTF *)newrtf)->PopupMenu = PopupMenu2;
+		if (mainmgr->config->Sections[mod->Name()]["ModDrv"] == "RawFiles") {
+			((SWDispRTF *)newrtf)->PopupMenu = PopupMenu3;
+			((SWDispRTF *)newrtf)->ExpandNewLine = false;
+		}
+		else	((SWDispRTF *)newrtf)->PopupMenu = PopupMenu2;
 		((SWDispRTF *)newrtf)->OnMouseDown = RTFMouseDown;
 	}
 
@@ -641,7 +647,15 @@ void __fastcall TForm1::PopupMenuPopup(TObject *Sender)
 	int versestart, verseend;
 	TMenuItem * newitem;
 	TPopupMenu *menu = (TPopupMenu *)Sender;
-	int staticMenuItemsCount = ((menu == PopupMenu1) ? 3:2);
+	int staticMenuItemsCount = 0;
+
+	if (menu == PopupMenu1)
+		staticMenuItemsCount = 3;
+	else if (menu == PopupMenu2)
+		staticMenuItemsCount = 2;
+	else if (menu == PopupMenu3)
+		staticMenuItemsCount = 6;
+		
 	while (menu->Items->Count > staticMenuItemsCount)
 		menu->Items->Delete(staticMenuItemsCount);
 
@@ -730,3 +744,58 @@ void __fastcall TForm1::RTFMouseDown(TObject *Sender, TMouseButton Button,
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TForm1::EditEntry1Click(TObject *Sender)
+{
+	SWDispRTF *rtf = (SWDispRTF *)Screen->ActiveControl;
+	SWModule *module = 0;
+	EditEntry->RichEdit1->Text = rtf->Text;
+	ModMap::iterator target;
+	target = mainmgr->Modules.find(((TPageControl*)rtf->Parent->Parent)->ActivePage->Caption.c_str());
+	if (target != Form1->mainmgr->Modules.end()) {
+		EditEntry->Module = module = (*target).second;
+		EditEntry->RTFDisplay = rtf;
+	}
+	else	EditEntry->Module = module = 0;
+	EditEntry->ShowModal();
+	if (EditEntry->ResultBuf) {
+		if (module)
+//			DictKeyEdit->Text = EditEntry->ResultBuf;  // for testing purposes
+			*module << EditEntry->ResultBuf;
+	}
+	RefreshActiveSheet(PageControl2);
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TForm1::DeleteEntry1Click(TObject *Sender)
+{
+	SWDispRTF *rtf = (SWDispRTF *)Screen->ActiveControl;
+	SWModule *module = 0;
+	ModMap::iterator target;
+
+	target = mainmgr->Modules.find(((TPageControl*)rtf->Parent->Parent)->ActivePage->Caption.c_str());
+	if (target != Form1->mainmgr->Modules.end()) {
+		module = (*target).second;
+		module->Delete();
+	}
+	RefreshActiveSheet(PageControl2);
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TForm1::LinktoVerse1Click(TObject *Sender)
+{
+	if (VerseSelFrm->ShowModal() == mrOk) {
+		SWDispRTF *rtf = (SWDispRTF *)Screen->ActiveControl;
+		SWModule *module = 0;
+		ModMap::iterator target;
+		SWKey *linkkey = new VerseKey(VerseSelFrm->Panel2->Caption.c_str());
+
+		target = mainmgr->Modules.find(((TPageControl*)rtf->Parent->Parent)->ActivePage->Caption.c_str());
+		if (target != Form1->mainmgr->Modules.end()) {
+			module = (*target).second;
+			*module << linkkey;
+		}
+		RefreshActiveSheet(PageControl2);
+	}
+}
+//---------------------------------------------------------------------------
+
