@@ -8,10 +8,12 @@
 #ifndef RAWSTR_H
 #define RAWSTR_H
 
+#include <filemgr.h>
+
 class RawStr {
 	static int instance;	// number of instantiated RawStr objects or derivitives
-	int idxfd;
-	int datfd;
+	FileDesc *idxfd;
+	FileDesc *datfd;
 	char *path;
 	long lastoff;
 
