@@ -49,6 +49,11 @@ public:
 	virtual operator char*() = 0;
 	virtual operator SWKey&() { return *key; }
 	virtual operator SWKey*() { return key; }
+
+	virtual SWModule &operator <<(const char *inbuf) { return *this; }  // Modify current module entry
+	virtual SWModule &operator <<(const SWKey *inkey) { return *this; } // Link current module entry to other module entry
+	virtual void Delete() {} // Delete current module entry
+
 	virtual SWModule &operator -=(int decrement);
 	virtual SWModule &operator +=(int increment);
 	virtual SWModule &operator ++(int) { return *this += 1; }
