@@ -43,7 +43,7 @@ class VerseKey : public SWKey {
 	char headings;		// flag for headings on/off
 
 	void initstatics();	// initialize and allocate books array
-	void freshtext();	// refresh keytext based on testament|book|chapter|verse
+	void freshtext() const;	// refresh keytext based on testament|book|chapter|verse
 	virtual char parse();	// Parse a character array into testament|book|chapter|verse
 	int findindex(long *array, int size, long value);	// finds the index of a given value
 public:
@@ -51,9 +51,10 @@ public:
 	static struct sbook *books[2];
 
 	VerseKey(const char *ikey = 0);
+	VerseKey(const SWKey *ikey);
 	virtual ~VerseKey();
 
-	virtual operator const char*();
+	virtual operator const char*() const;
 	virtual SWKey &operator =(const char * ikey) {SWKey &retval = SWKey::operator =(ikey); parse(); return retval; }
 	virtual SWKey &operator =(SWKey &ikey);
 	virtual SWKey &operator =(POSITION);
@@ -79,9 +80,9 @@ public:
 
 	static SWListKey &ParseVerseList(char *buf, const char *defaultKey = "Genesis 1:1");
 
-	virtual char operator ==(SWKey &ikey);
-	virtual char operator  >(SWKey &ikey);
-	virtual char operator  <(SWKey &ikey);
+	virtual bool operator ==(const SWKey &ikey);
+	virtual bool operator  >(const SWKey &ikey);
+	virtual bool operator  <(const SWKey &ikey);
 };
 
 
