@@ -32,6 +32,25 @@ int           VerseKey::instance       = 0;
 SWListKey     VerseKey::internalListKey;
 
 
+/******************************************************************************
+ * VerseKey Constructor - initializes instance of VerseKey
+ *
+ * ENT:	ikey - base key (will take various forms of 'BOOK CH:VS'.  See
+ *		VerseKey::parse for more detailed information)
+ */
+
+VerseKey::VerseKey(const SWKey *ikey) : SWKey(*ikey)
+{
+	if (!instance)
+		initstatics();
+
+	instance++;
+	autonorm = 1;		// default auto normalization to true
+     headings = 0;		// default display headings option is false
+	parse();
+}
+
+
 /******************************************************************************
  * VerseKey Constructor - initializes instance of VerseKey
  *
@@ -132,7 +151,7 @@ char VerseKey::parse()
  *				testament|book|chapter|verse
  */
 
-void VerseKey::freshtext()
+void VerseKey::freshtext() const
 {
 	char buf[45];
 
@@ -143,7 +162,7 @@ void VerseKey::freshtext()
 	}
 	else sprintf(buf, "%s %d:%d", books[testament-1][book-1].name, chapter, verse);
 
-	stdstr(&keytext, buf);
+	stdstr((char **)&keytext, buf);
 }
 
 
@@ -157,7 +176,7 @@ void VerseKey::freshtext()
 
 int VerseKey::getBookAbbrev(char *abbr)
 {
-	int loop;
+	unsigned int loop;
 
 	strstrip(abbr);
 	for (loop = 0; loop < strlen(abbr); loop++)
@@ -186,14 +205,12 @@ SWListKey &VerseKey::ParseVerseList(char *buf, const char *defaultKey)
 	SWKey textkey;
 
 	char book[255];
-	char lastbook[255];
 	char number[255];
-	char lastnumber[255];
 	char tobook = 0;
 	char tonumber = 0;
 	char lastchar = 0;
 	int chap = -1, verse = -1;
-	int bookno;
+	int bookno = 0;
 	VerseKey curkey;
 	int loop;
 	char comma = 0;
@@ -201,6 +218,7 @@ SWListKey &VerseKey::ParseVerseList(char *buf, const char *defaultKey)
 	SWListKey tmpListKey;
 	SWKey tmpDefaultKey = defaultKey;
 
+	curkey.AutoNormalize(0);
 	tmpListKey << tmpDefaultKey;
 	
 	while (*buf) {
@@ -390,7 +408,7 @@ SWKey &VerseKey::operator =(SWKey &ikey)
  *				a (char *) is requested
  */
 
-VerseKey::operator const char *()
+VerseKey::operator const char *() const
 {
 	freshtext();
 	return keytext;
@@ -855,7 +873,7 @@ long VerseKey::Index(long iindex)
  * RET:	if this key is equal to ikey
  */
 
-char VerseKey::operator ==(SWKey &ikey)
+bool VerseKey::operator ==(const SWKey &ikey)
 {
 	VerseKey ivkey = (const char *)ikey;
 
@@ -876,7 +894,7 @@ char VerseKey::operator ==(SWKey &ikey)
  * RET:	if this key is greater than ikey
  */
 
-char VerseKey::operator >(SWKey &ikey)
+bool VerseKey::operator >(const SWKey &ikey)
 {
 	VerseKey *ivkey = (VerseKey *)&ikey;
 
@@ -898,7 +916,7 @@ char VerseKey::operator >(SWKey &ikey)
  * RET:	if this key is less than ikey
  */
 
-char VerseKey::operator <(SWKey &ikey)
+bool VerseKey::operator <(const SWKey &ikey)
 {
 	VerseKey *ivkey = (VerseKey *)&ikey;
 
