@@ -13,6 +13,7 @@
 #include <utilfuns.h>
 #include <gbfrtf.h>
 #include <rwprtf.h>
+#include <rawfiles.h>
 
 
 SWMgr::SWMgr(SWConfig *iconfig, bool autoload) {
@@ -82,6 +83,10 @@ void SWMgr::CreateMods() {
 				newmod = new RawCom(datapath.c_str(), (*it).first.c_str(), description.c_str());
 			}
 						
+			if (!stricmp(driver.c_str(), "RawFiles")) {
+				newmod = new RawFiles(datapath.c_str(), (*it).first.c_str(), description.c_str());
+			}
+						
 			if (!stricmp(driver.c_str(), "HREFCom")) {
 				misc1 = (*it).second["Prefix"];
 				newmod = new HREFCom(datapath.c_str(), misc1.c_str(), (*it).first.c_str(), description.c_str());
