@@ -6,6 +6,7 @@
 #include <rawcom.h>
 #include <rawgbf.h>
 #include <stdlib.h>
+#include <rawfiles.h>
 
 int main(int argc, char **argv)
 {
@@ -18,7 +19,8 @@ int main(int argc, char **argv)
 //	RawText webster("modules/texts/rawtext/kjv/", "KJV", "KJV Text");
 //	RawText webster("modules/texts/rawtext/vnt/", "VNT", "Valera Spanish NT");
 //	RawCom  mhc("modules/comments/rawcom/rwp/", "RWP", "Robertson's Word Pictures");
-	RawCom  mhc("modules/comments/rawcom/mhc/", "MHC", "Matthew Henry's Commentary on the Whole Bible");
+//	RawCom  mhc("modules/comments/rawcom/mhc/", "MHC", "Matthew Henry's Commentary on the Whole Bible");
+	RawFiles  mhc("modules/comments/rawfiles/personal/", "MHC", "Matthew Henry's Commentary on the Whole Bible");
 	VerseKey mykey;
 
 	if (argc > 3)
@@ -40,9 +42,9 @@ int main(int argc, char **argv)
 		webster.Display();
 		cout << "\n";
 		cout << "-------------\n";
-//		mhc.Display();
-//		cout << "\n";
-//		cout << "==========================\n";
+		mhc.Display();
+		cout << "\n";
+		cout << "==========================\n";
 		mykey++;
 	}
 	cout << "\n\n";
